@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -18,7 +18,7 @@ import { CustomObjectsApi } from '@kubernetes/client-node';
 import { CheClusterCustomResource, CustomResourceDefinitionList } from '@/devworkspaceClient';
 import { ServerConfigApiService } from '@/devworkspaceClient/services/serverConfigApi';
 
-jest.mock('../../../helpers/getUserName.ts');
+jest.mock('@/helpers/getUserName.ts');
 
 describe('Server Config API Service', () => {
   const env = process.env;
