@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -34,7 +34,7 @@ jest.mock('../helpers', () => {
     toSecret: (...args: Parameters<(typeof originalModule)['toSecret']>) => mockToSecret(...args),
   };
 });
-jest.mock('../../helpers/retryableExec');
+jest.mock('@/devworkspaceClient/services/helpers/retryableExec.ts');
 
 const namespace = 'user-che';
 
