@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -16,7 +16,7 @@ export function stubCheServerOptionsRequests(server: FastifyInstance) {
   // stub OPTIONS requests to '/api/' since they fail when running the backend locally.
   server.addHook('onRequest', (request, reply, done) => {
     if ((request.url === '/api' || request.url === '/api/') && request.method === 'OPTIONS') {
-      return reply.send({
+      reply.send({
         implementationVersion: 'Local Run',
       });
     }
