@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -17,10 +17,10 @@ export function registerDexCallback(server: FastifyInstance) {
     try {
       const { token } = await server.localStart.getAccessTokenFromAuthorizationCodeFlow(request);
       process.env.CLUSTER_ACCESS_TOKEN = token.access_token;
-      return reply.redirect('/dashboard/');
+      reply.redirect('/dashboard/');
     } catch (e) {
       // handle an error that usually occurs during the authorization flow from an abandoned tab with outdated state
-      return reply.redirect('/oauth/sign_in');
+      reply.redirect('/oauth/sign_in');
     }
   });
 }
