@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -63,6 +63,16 @@ describe('DevWorkspaceTemplates Routes', () => {
       expect(res.json()).toEqual(stubDevWorkspaceTemplate);
     });
 
+    test('GET ${baseApiPath}/namespace/:namespace/devworkspacetemplates/:templateName', async () => {
+      const templateName = 'tmpl';
+      const res = await app
+        .inject()
+        .get(`${baseApiPath}/namespace/${namespace}/devworkspacetemplates/${templateName}`);
+
+      expect(res.statusCode).toEqual(200);
+      expect(res.json()).toEqual(stubDevWorkspaceTemplate);
+    });
+
     test('PATCH ${baseApiPath}/namespace/:namespace/devworkspacetemplates/:templateName', async () => {
       const templateName = 'tmpl';
       const patches: api.IPatch[] = [
