@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -57,8 +57,7 @@ export function registerDevworkspacesRoutes(instance: FastifyInstance) {
         const { devworkspaceApi } = getDevWorkspaceClient(token);
         const { headers, devWorkspace } = await devworkspaceApi.create(devworkspace, namespace);
 
-        reply.headers(headers);
-        reply.send(devWorkspace);
+        reply.headers(headers).send(devWorkspace);
       },
     );
 
@@ -89,8 +88,7 @@ export function registerDevworkspacesRoutes(instance: FastifyInstance) {
           patch,
         );
 
-        reply.headers(headers);
-        reply.send(devWorkspace);
+        reply.headers(headers).send(devWorkspace);
       },
     );
 
@@ -111,9 +109,10 @@ export function registerDevworkspacesRoutes(instance: FastifyInstance) {
           request.params as restParams.INamespacedWorkspaceParams;
         const token = getToken(request);
         const { devworkspaceApi } = getDevWorkspaceClient(token);
+
         await devworkspaceApi.delete(namespace, workspaceName);
-        reply.code(204);
-        return reply.send();
+
+        reply.code(204).send();
       },
     );
   });
