@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -31,27 +31,27 @@ import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
 
 import Routes from '..';
 
-jest.mock('../../pages/GetStarted', () => {
+jest.mock('@/pages/GetStarted', () => {
   return function GetStarted() {
     return <span>Quick Add</span>;
   };
 });
-jest.mock('../../containers/WorkspacesList.tsx', () => {
+jest.mock('@/containers/WorkspacesList.tsx', () => {
   return function WorkspacesList() {
     return <span>Workspaces List</span>;
   };
 });
-jest.mock('../../containers/WorkspaceDetails', () => {
+jest.mock('@/containers/WorkspaceDetails', () => {
   return function WorkspaceDetails() {
     return <span>Workspace Details</span>;
   };
 });
-jest.mock('../../containers/Loader', () => {
+jest.mock('@/containers/Loader', () => {
   return function Loader() {
     return <span>Loader</span>;
   };
 });
-jest.mock('../../pages/UserPreferences', () => {
+jest.mock('@/pages/UserPreferences', () => {
   return function UserPreferences() {
     return <span>User Preferences</span>;
   };
