@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -43,7 +43,7 @@ import Routes from '@/Routes';
 import devfileApi from '@/services/devfileApi';
 import { AppState } from '@/store';
 import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
-import { ConvertedState } from '@/store/FactoryResolver';
+import { ConvertedState, ResolverState } from '@/store/FactoryResolver';
 
 // mute the outputs
 console.error = jest.fn();
@@ -86,12 +86,22 @@ describe('Workspace creation time', () => {
     const { rerender } = render(
       getComponent(
         `/load-factory?url=${url}`,
-        new FakeStoreBuilder().withInfrastructureNamespace([namespace]).build(),
+        new FakeStoreBuilder()
+          .withInfrastructureNamespace([namespace])
+          .withSshKeys({
+            keys: [
+              {
+                name: 'test',
+                keyPub: 'test',
+              },
+            ],
+          })
+          .build(),
       ),
     );
 
     await waitFor(
-      () => expect(mockPost).toBeCalledWith('/api/factory/resolver', expect.anything()),
+      () => expect(mockPost).toHaveBeenCalledWith('/api/factory/resolver', expect.anything()),
       { timeout: 8000 },
     );
     expect(mockPost).toHaveBeenCalledTimes(1);
@@ -162,7 +172,7 @@ describe('Workspace creation time', () => {
           .withInfrastructureNamespace([namespace])
           .withFactoryResolver({
             resolver: Object.assign(
-              { location: 'https://github.com/eclipse-che/che-dashboard' },
+              { location: 'https://github.com/eclipse-che/che-dashboard' } as ResolverState,
               factoryResolver,
             ),
             converted: {
@@ -176,7 +186,7 @@ describe('Workspace creation time', () => {
             },
             pluginRegistryURL: 'http://localhost/plugin-registry/v3',
           } as api.IServerConfig)
-          .withDwPlugins(plugins)
+          .withDwPlugins(plugins, {}, false)
           .withDevfileRegistries({
             devfiles: {
               ['http://localhost/plugin-registry/v3/plugins/che-incubator/che-code/insiders/devfile.yaml']:
@@ -205,7 +215,7 @@ describe('Workspace creation time', () => {
         ]),
       { timeout: 1500 },
     );
-    expect(mockPost).toBeCalledTimes(3);
+    expect(mockPost).toHaveBeenCalledTimes(3);
 
     await waitFor(
       () =>
@@ -216,8 +226,8 @@ describe('Workspace creation time', () => {
         ]),
       { timeout: 1500 },
     );
-    expect(mockPatch).toBeCalledTimes(1);
-    expect(mockGet).not.toBeCalled();
+    expect(mockPatch).toHaveBeenCalledTimes(1);
+    expect(mockGet).not.toHaveBeenCalled();
     expect(screen.queryByTestId('fallback-spinner')).not.toBeInTheDocument();
 
     expect(execTime).toBeLessThan(TIME_LIMIT);
