@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -19,7 +19,7 @@ import getComponentRenderer, { screen } from '@/services/__mocks__/getComponentR
 
 import { NO_CONTAINERS, WorkspaceLogsContainerSelector } from '..';
 
-jest.mock('../../../../components/ResourceIcon');
+jest.mock('@/components/ResourceIcon');
 
 const { createSnapshot, renderComponent } = getComponentRenderer(getComponent);
 
