@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -226,7 +226,7 @@ class CreatingStepApplyResources extends ProgressStep<Props, State> {
       return false;
     }
 
-    await this.props.createWorkspaceFromResources(...resources, cheEditor);
+    await this.props.createWorkspaceFromResources(...resources, factoryParams, cheEditor);
 
     // wait for the workspace creation to complete
     return false;
