@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -99,6 +99,21 @@ describe('Creating steps, fetching a devfile', () => {
     jest.useRealTimers();
   });
 
+  test('factory should not resolve the SSH location', async () => {
+    const searchParams = new URLSearchParams({
+      [FACTORY_URL_ATTR]: 'git@github.com:eclipse-che/che-dashboard.git',
+    });
+
+    renderComponent(store, searchParams);
+
+    await jest.advanceTimersByTimeAsync(MIN_STEP_DURATION_MS);
+
+    await waitFor(() => expect(mockOnNextStep).toHaveBeenCalled());
+    expect(mockOnError).not.toHaveBeenCalled();
+    expect(mockOnRestart).not.toHaveBeenCalled();
+    expect(mockRequestFactoryResolver).not.toHaveBeenCalled();
+  });
+
   test('devfile is already resolved', async () => {
     renderComponent(store, searchParams);
 
