@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -27,10 +27,10 @@ import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
 
 import StartingStepOpenWorkspace from '..';
 
-jest.mock('../../../TimeLimit');
+jest.mock('@/components/WorkspaceProgress/TimeLimit');
 
 const isAvailableEndpointMock = jest.fn();
-jest.mock('../../../../../services/helpers/api-ping', () => ({
+jest.mock('@/services/helpers/api-ping', () => ({
   isAvailableEndpoint: (url: string | undefined) => isAvailableEndpointMock(url),
 }));
 
