@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -26,11 +26,11 @@ import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
 
 import LoaderContainer from '..';
 
-jest.mock('../../../pages/Loader');
+jest.mock('@/pages/Loader');
 
 const mockFindTargetWorkspace = jest.fn().mockReturnValue(undefined);
 // const mockFindTargetWorkspace = jest.fn();
-jest.mock('../../../services/helpers/factoryFlow/findTargetWorkspace', () => ({
+jest.mock('@/services/helpers/factoryFlow/findTargetWorkspace', () => ({
   __esModule: true,
   findTargetWorkspace: () => mockFindTargetWorkspace(),
 }));
