@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -27,7 +27,7 @@ import { ActionCreators } from '@/store/Workspaces';
 
 import { ActionContextType, WorkspaceActionsConsumer } from '..';
 
-jest.mock('../../../store/Workspaces/index', () => {
+jest.mock('@/store/Workspaces/index', () => {
   /* eslint-disable @typescript-eslint/no-unused-vars */
   return {
     actionCreators: {
