@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -12,16 +12,23 @@
 
 import { api } from '@eclipse-che/common';
 import { render, RenderResult, screen } from '@testing-library/react';
+import { createMemoryHistory } from 'history';
 import React from 'react';
 import { Provider } from 'react-redux';
 
 import { BrandingData } from '@/services/bootstrap/branding.constant';
 import devfileApi from '@/services/devfileApi';
+import { che } from '@/services/models';
 import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
 import { selectPvcStrategy } from '@/store/ServerConfig/selectors';
 
 import { SamplesListTab } from '..';
 
+jest.mock('@/pages/GetStarted/GetStartedTab/ImportFromGit');
+const history = createMemoryHistory({
+  initialEntries: ['/'],
+});
+
 const onDevfileMock: (
   devfileContent: string,
   stackName: string,
@@ -83,6 +90,8 @@ describe('Samples list tab', () => {
     return render(
       <Provider store={store}>
         <SamplesListTab
+          sshKeys={[]}
+          history={history}
           onDevfile={onDevfileMock}
           preferredStorageType={selectPvcStrategy(state)}
           dispatch={jest.fn()}
