@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -32,9 +32,9 @@ jest.mock('react-tooltip', () => {
   };
 });
 
-jest.mock('../../../components/WorkspaceProgress');
-jest.mock('../../../components/WorkspaceLogs');
-jest.mock('../../../components/WorkspaceEvents');
+jest.mock('@/components/WorkspaceProgress');
+jest.mock('@/components/WorkspaceLogs');
+jest.mock('@/components/WorkspaceEvents');
 
 const { renderComponent } = getComponentRenderer(getComponent);
 
