@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -31,7 +31,7 @@ import { ActionCreators, ResourceQueryParams } from '@/store/Workspaces';
 import { HeaderActionSelect } from '..';
 
 /* eslint-disable @typescript-eslint/no-unused-vars */
-jest.mock('../../../../../store/Workspaces/index', () => {
+jest.mock('@/store/Workspaces/index', () => {
   return {
     actionCreators: {
       startWorkspace:
@@ -116,7 +116,10 @@ describe('Workspace WorkspaceAction widget', () => {
     targetAction.click();
 
     await waitFor(() =>
-      expect(window.open).toBeCalledWith(`#/ide/${namespace}/test-workspace-name`, workspaceUID),
+      expect(window.open).toHaveBeenCalledWith(
+        `#/ide/${namespace}/test-workspace-name`,
+        workspaceUID,
+      ),
     );
   });
 
@@ -136,7 +139,10 @@ describe('Workspace WorkspaceAction widget', () => {
     targetAction.click();
 
     await waitFor(() =>
-      expect(window.open).toBeCalledWith(`#/ide/${namespace}/test-workspace-name`, workspaceUID),
+      expect(window.open).toHaveBeenCalledWith(
+        `#/ide/${namespace}/test-workspace-name`,
+        workspaceUID,
+      ),
     );
   });
 
