@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -25,7 +25,7 @@ import { DevWorkspaceBuilder } from '@/store/__mocks__/devWorkspaceBuilder';
 
 import WorkspacesList from '..';
 
-jest.mock('../../../components/Head', () => {
+jest.mock('@/components/Head', () => {
   const FakeHead = () => {
     return <span>Dummy Head Component</span>;
   };
