@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -18,6 +18,7 @@ import { Store } from 'redux';
 
 import PreloadData from '@/services/bootstrap';
 import { BrandingData } from '@/services/bootstrap/branding.constant';
+import { che } from '@/services/models';
 import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
 
 jest.mock('@/services/helpers/delay', () => ({ delay: jest.fn() }));
@@ -30,6 +31,7 @@ jest.mock('@/services/resource-fetcher/appendLink', () => {
 });
 
 // mute the outputs
+console.error = jest.fn();
 console.log = jest.fn();
 
 describe('Dashboard bootstrap', () => {
@@ -66,7 +68,7 @@ describe('Dashboard bootstrap', () => {
 
   test('requests which should be sent', async () => {
     prepareMocks(mockPost, 1, namespace); // provisionNamespace
-    prepareMocks(mockGet, 15, []); // branding, namespace, prefetch, server-config, cluster-info, userprofile, plugin-registry, default-editor, devfile-registry, getting-started-sample, devworkspacetemplates, devworkspaces, events, pods, cluster-config
+    prepareMocks(mockGet, 16, []); // branding, namespace, prefetch, server-config, cluster-info, userprofile, plugin-registry, default-editor, devfile-registry, getting-started-sample, devworkspaces, events, pods, cluster-config, ssh-key
 
     await preloadData.init();
 
@@ -79,12 +81,16 @@ describe('Dashboard bootstrap', () => {
     );
     // wait for all GET requests to be sent
     await waitFor(() => expect(mockGet).toHaveBeenCalledTimes(15));
+
+    await waitFor(() =>
+      expect(mockGet).toHaveBeenCalledWith('/dashboard/api/namespace/test-che/ssh-key', undefined),
+    );
     expect(mockGet).toHaveBeenCalledWith('./assets/branding/product.json');
     expect(mockGet).toHaveBeenCalledWith('/api/kubernetes/namespace', undefined);
     expect(mockGet).toHaveBeenCalledWith('https://prefetch-che-cdn.test', {
       headers: { 'Cache-Control': 'no-cache', Expires: '0' },
     });
-    expect(mockGet).toHaveBeenCalledWith('/dashboard/api/server-config');
+    expect(mockGet).toHaveBeenCalledWith('/dashboard/api/server-config', undefined);
     expect(mockGet).toHaveBeenCalledWith('/dashboard/api/cluster-info');
     expect(mockGet).toHaveBeenCalledWith('/dashboard/api/userprofile/test-che', undefined);
     expect(mockGet).toHaveBeenCalledWith('/plugin-registry/v3/plugins/index.json');
@@ -93,10 +99,6 @@ describe('Dashboard bootstrap', () => {
       'http://localhost/dashboard/devfile-registry/devfiles/index.json',
     );
     expect(mockGet).toHaveBeenCalledWith('http://localhost/dashboard/api/getting-started-sample');
-    expect(mockGet).toHaveBeenCalledWith(
-      '/dashboard/api/namespace/test-che/devworkspacetemplates',
-      undefined,
-    );
     expect(mockGet).toHaveBeenCalledWith(
       '/dashboard/api/namespace/test-che/devworkspaces',
       undefined,
