@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,7 +10,7 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import common, { api, ApplicationId } from '@eclipse-che/common';
+import common, { api } from '@eclipse-che/common';
 import { Store } from 'redux';
 
 import { lazyInject } from '@/inversify.config';
@@ -26,19 +26,16 @@ import {
   WorkspaceRunningError,
   WorkspaceStoppedDetector,
 } from '@/services/bootstrap/workspaceStoppedDetector';
-import devfileApi from '@/services/devfileApi';
 import { isAvailableEndpoint } from '@/services/helpers/api-ping';
 import { buildDetailsLocation, buildIdeLoaderLocation } from '@/services/helpers/location';
 import { ResourceFetcherService } from '@/services/resource-fetcher';
 import { Workspace } from '@/services/workspace-adapter';
-import { DevWorkspaceClient } from '@/services/workspace-client/devworkspace/devWorkspaceClient';
 import { AppState } from '@/store';
 import * as BannerAlertStore from '@/store/BannerAlert';
 import * as BrandingStore from '@/store/Branding';
 import * as ClusterConfigStore from '@/store/ClusterConfig';
 import { selectDashboardFavicon } from '@/store/ClusterConfig/selectors';
 import * as ClusterInfoStore from '@/store/ClusterInfo';
-import { selectApplications } from '@/store/ClusterInfo/selectors';
 import * as DevfileRegistriesStore from '@/store/DevfileRegistries';
 import { DEFAULT_REGISTRY } from '@/store/DevfileRegistries';
 import { selectEmptyWorkspaceUrl } from '@/store/DevfileRegistries/selectors';
@@ -48,19 +45,19 @@ import * as InfrastructureNamespacesStore from '@/store/InfrastructureNamespaces
 import { selectDefaultNamespace } from '@/store/InfrastructureNamespaces/selectors';
 import * as PluginsStore from '@/store/Plugins/chePlugins';
 import * as DwPluginsStore from '@/store/Plugins/devWorkspacePlugins';
-import { selectDwEditorsPluginsList } from '@/store/Plugins/devWorkspacePlugins/selectors';
 import * as PodsStore from '@/store/Pods';
 import { selectPodsResourceVersion } from '@/store/Pods/selectors';
 import * as SanityCheckStore from '@/store/SanityCheck';
 import * as ServerConfigStore from '@/store/ServerConfig';
-import { selectOpenVSXUrl, selectPluginRegistryUrl } from '@/store/ServerConfig/selectors';
+import { selectPluginRegistryUrl } from '@/store/ServerConfig/selectors';
+import * as SshKeysStore from '@/store/SshKeys';
 import * as UserProfileStore from '@/store/User/Profile';
 import * as WorkspacesStore from '@/store/Workspaces';
 import * as DevWorkspacesStore from '@/store/Workspaces/devWorkspaces';
 import { selectDevWorkspacesResourceVersion } from '@/store/Workspaces/devWorkspaces/selectors';
 
 /**
- * This class executes a few initial instructions
+ * This class executes initial instructions
  * @author Oleksii Orel
  */
 export default class Bootstrap {
@@ -70,9 +67,6 @@ export default class Bootstrap {
   @lazyInject(WebsocketClient)
   private readonly websocketClient: WebsocketClient;
 
-  @lazyInject(DevWorkspaceClient)
-  private readonly devWorkspaceClient: DevWorkspaceClient;
-
   @lazyInject(WorkspaceStoppedDetector)
   private readonly workspaceStoppedDetector: WorkspaceStoppedDetector;
 
@@ -101,7 +95,6 @@ export default class Bootstrap {
       this.fetchDwPlugins(),
       this.fetchDefaultDwPlugins(),
       this.fetchRegistriesMetadata().then(() => this.fetchEmptyWorkspace()),
-      this.updateDevWorkspaceTemplates(),
       this.fetchWorkspaces().then(() => {
         this.checkWorkspaceStopped();
         return this.watchWebSocketDevWorkspaces();
@@ -113,6 +106,7 @@ export default class Bootstrap {
         this.watchWebSocketPods();
       }),
       this.fetchClusterConfig().then(() => this.updateFavicon()),
+      this.fetchSshKeys(),
     ]);
 
     const errors = results
@@ -302,37 +296,6 @@ export default class Bootstrap {
     }
   }
 
-  private async updateDevWorkspaceTemplates(): Promise<void> {
-    const defaultKubernetesNamespace = selectDefaultNamespace(this.store.getState());
-    const defaultNamespace = defaultKubernetesNamespace.name;
-    try {
-      const pluginsByUrl: { [url: string]: devfileApi.Devfile } = {};
-      const state = this.store.getState();
-      selectDwEditorsPluginsList(state.dwPlugins.defaultEditorName)(state).forEach(dwEditor => {
-        pluginsByUrl[dwEditor.url] = dwEditor.devfile;
-      });
-      const openVSXUrl = selectOpenVSXUrl(state);
-      const pluginRegistryUrl = selectPluginRegistryUrl(state);
-      const pluginRegistryInternalUrl = state.dwServerConfig.config.pluginRegistryInternalURL;
-      const clusterConsole = selectApplications(state).find(
-        app => app.id === ApplicationId.CLUSTER_CONSOLE,
-      );
-      const updates = await this.devWorkspaceClient.checkForTemplatesUpdate(
-        defaultNamespace,
-        pluginsByUrl,
-        pluginRegistryUrl,
-        pluginRegistryInternalUrl,
-        openVSXUrl,
-        clusterConsole,
-      );
-      if (Object.keys(updates).length > 0) {
-        await this.devWorkspaceClient.updateTemplates(defaultNamespace, updates);
-      }
-    } catch (e) {
-      console.error('Failed to update templates.', e);
-    }
-  }
-
   private async fetchInfrastructureNamespaces(): Promise<void> {
     const { requestNamespaces } = InfrastructureNamespacesStore.actionCreators;
     try {
@@ -480,4 +443,9 @@ export default class Bootstrap {
       }
     }
   }
+
+  private async fetchSshKeys(): Promise<void> {
+    const { requestSshKeys } = SshKeysStore.actionCreators;
+    await requestSshKeys()(this.store.dispatch, this.store.getState, undefined);
+  }
 }
