@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -12,9 +12,10 @@
 
 import devfileApi, { isDevfileV2 } from '@/services/devfileApi';
 import { DEVWORKSPACE_STORAGE_TYPE_ATTR } from '@/services/devfileApi/devWorkspace/spec/template';
+import { che } from '@/services/models';
 import { attributesToType } from '@/services/storageTypes';
 
-export type Devfile = che.WorkspaceDevfile | devfileApi.Devfile;
+export type Devfile = che.api.workspace.devfile.Devfile | devfileApi.Devfile;
 
 export class DevfileAdapter {
   private _devfile: Devfile;
