@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -13,9 +13,10 @@
 import * as devfileConverter from '@eclipse-che/devfile-converter';
 
 import devfileApi from '@/services/devfileApi';
+import { che } from '@/services/models';
 
 export async function convertDevfileV1toDevfileV2(
-  devfile: che.WorkspaceDevfile,
+  devfile: che.api.workspace.devfile.Devfile,
 ): Promise<devfileApi.Devfile> {
   const converted = (await devfileConverter.v1ToV2(devfile)) as devfileApi.Devfile;
 
