@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -107,9 +107,9 @@ describe('test API endpoints', () => {
 
     const isAvailable = await isAvailableEndpoint(endpoint);
 
-    expect(delayMock).toBeCalledWith(2500);
+    expect(delayMock).toHaveBeenCalledWith(2500);
     expect(delayMock).toHaveBeenCalledTimes(11);
-    expect(console.error).toBeCalledWith(
+    expect(console.error).toHaveBeenCalledWith(
       `Endpoint 'https://example.com/developer-image/3100/' is not available. Error: 503 Service Unavailable.`,
     );
     expect(isAvailable).toBeFalsy();
@@ -128,9 +128,9 @@ describe('test API endpoints', () => {
 
     const isAvailable = await isAvailableEndpoint(endpoint);
 
-    expect(delayMock).toBeCalledWith(2500);
+    expect(delayMock).toHaveBeenCalledWith(2500);
     expect(delayMock).toHaveBeenCalledTimes(11);
-    expect(console.error).toBeCalledWith(
+    expect(console.error).toHaveBeenCalledWith(
       `Endpoint 'https://example.com/developer-image/3100/' is not available. Error: 404 Page Not Found.`,
     );
     expect(isAvailable).toBeFalsy();
