@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,6 +10,8 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
+import { che } from '@/services/models';
+
 export const DEV_WORKSPACE_ATTR = 'devWorkspace';
 export const EDITOR_ATTR = 'che-editor';
 export const ERROR_CODE_ATTR = 'error_code';
@@ -18,6 +20,7 @@ export const POLICIES_CREATE_ATTR = 'policies.create';
 export const STORAGE_TYPE_ATTR = 'storageType';
 export const REMOTES_ATTR = 'remotes';
 export const IMAGE_ATTR = 'image';
+export const EDITOR_IMAGE_ATTR = 'editor-image';
 export const USE_DEFAULT_DEVFILE = 'useDefaultDevfile';
 export const DEBUG_WORKSPACE_START = 'debugWorkspaceStart';
 export const PROPAGATE_FACTORY_ATTRS = [
@@ -30,6 +33,7 @@ export const PROPAGATE_FACTORY_ATTRS = [
   STORAGE_TYPE_ATTR,
   REMOTES_ATTR,
   IMAGE_ATTR,
+  EDITOR_IMAGE_ATTR,
 ];
 export const OVERRIDE_ATTR_PREFIX = 'override.';
 export const DEFAULT_POLICIES_CREATE = 'peruser';
@@ -39,11 +43,12 @@ export type FactoryParams = {
   factoryUrl: string;
   policiesCreate: PoliciesCreate;
   sourceUrl: string;
-  useDevworkspaceResources: boolean;
+  useDevWorkspaceResources: boolean;
   overrides: Record<string, string> | undefined;
   errorCode: ErrorCode | undefined;
   storageType: che.WorkspaceStorageType | undefined;
   cheEditor: string | undefined;
+  editorImage: string | undefined;
   remotes: string | undefined;
   image: string | undefined;
   useDefaultDevfile: boolean;
@@ -57,6 +62,7 @@ export type ErrorCode = 'invalid_request' | 'access_denied';
 export function buildFactoryParams(searchParams: URLSearchParams): FactoryParams {
   return {
     cheEditor: getEditorId(searchParams),
+    editorImage: getEditorImage(searchParams),
     errorCode: getErrorCode(searchParams),
     factoryId: buildFactoryId(searchParams),
     factoryUrl: getFactoryUrl(searchParams),
@@ -65,7 +71,7 @@ export function buildFactoryParams(searchParams: URLSearchParams): FactoryParams
     sourceUrl: getSourceUrl(searchParams),
     storageType: getStorageType(searchParams),
     remotes: getRemotes(searchParams),
-    useDevworkspaceResources: getDevworkspaceResourcesUrl(searchParams) !== undefined,
+    useDevWorkspaceResources: getDevworkspaceResourcesUrl(searchParams) !== undefined,
     image: getImage(searchParams),
     useDefaultDevfile: isSafeWorkspaceStart(searchParams) !== undefined,
     debugWorkspaceStart: isDebugWorkspaceStart(searchParams) !== undefined,
@@ -106,6 +112,10 @@ function getEditorId(searchParams: URLSearchParams): string | undefined {
   return searchParams.get(EDITOR_ATTR) || undefined;
 }
 
+function getEditorImage(searchParams: URLSearchParams): string | undefined {
+  return searchParams.get(EDITOR_IMAGE_ATTR) || undefined;
+}
+
 function getErrorCode(searchParams: URLSearchParams): ErrorCode | undefined {
   return (searchParams.get(ERROR_CODE_ATTR) as ErrorCode) || undefined;
 }
