@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,11 +10,11 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import * as cheApi from '@eclipse-che/api';
 import { AlertVariant } from '@patternfly/react-core';
 import * as React from 'react';
 
 import devfileApi from '@/services/devfileApi';
+import { che } from '@/services/models';
 
 export type ActionCallback = {
   title: string;
@@ -31,13 +31,10 @@ export interface AlertItem {
   timeout?: boolean | number;
 }
 
-export interface FactoryResolver {
-  v: string;
-  source?: string;
-  devfile: devfileApi.Devfile | che.WorkspaceDevfile;
+export interface FactoryResolver extends Omit<che.api.factory.Factory, 'devfile'> {
+  devfile: che.api.workspace.devfile.Devfile | devfileApi.Devfile;
   location?: string;
   scm_info?: FactoryResolverScmInfo;
-  links: cheApi.che.core.rest.Link[];
 }
 
 export type FactoryResolverScmInfo = {
@@ -105,9 +102,10 @@ export enum WorkspaceAction {
   WORKSPACE_DETAILS = 'Workspace Details',
 }
 
-export type UserPreferencesTab =
-  | 'container-registries'
-  | 'git-services'
-  | 'gitconfig'
-  | 'personal-access-tokens'
-  | 'ssh-keys';
+export enum UserPreferencesTab {
+  CONTAINER_REGISTRIES = 'ContainerRegistries',
+  GIT_SERVICES = 'GitServices',
+  GITCONFIG = 'Gitconfig',
+  PERSONAL_ACCESS_TOKENS = 'PersonalAccessTokens',
+  SSH_KEYS = 'SshKeys',
+}
