@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -18,6 +18,7 @@ import {
   DevWorkspaceStatus,
   WorkspaceStatus,
 } from '@/services/helpers/types';
+import { che } from '@/services/models';
 import {
   devfileToDevWorkspace,
   devWorkspaceToDevfile,
@@ -274,6 +275,6 @@ export function constructWorkspace<T extends devfileApi.DevWorkspace>(workspace:
   return new WorkspaceAdapter(workspace);
 }
 
-export function isCheDevfile(devfile: unknown): devfile is che.WorkspaceDevfile {
+export function isCheDevfile(devfile: unknown): devfile is che.api.workspace.devfile.Devfile {
   return !isDevfileV2(devfile);
 }
