@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -109,7 +109,7 @@ describe('DevWorkspace client, create', () => {
         openVSXUrl,
       );
 
-      expect(spyCreateWorkspaceTemplate).toBeCalledWith(
+      expect(spyCreateWorkspaceTemplate).toHaveBeenCalledWith(
         expect.objectContaining({
           spec: expect.objectContaining({
             components: expect.arrayContaining([
@@ -155,7 +155,7 @@ describe('DevWorkspace client, create', () => {
         clusterConsole,
       );
 
-      expect(spyCreateWorkspaceTemplate).toBeCalledWith(
+      expect(spyCreateWorkspaceTemplate).toHaveBeenCalledWith(
         expect.objectContaining({
           spec: expect.objectContaining({
             components: expect.arrayContaining([
@@ -193,7 +193,7 @@ describe('DevWorkspace client, create', () => {
         openVSXUrl,
       );
 
-      expect(spyCreateWorkspaceTemplate).toBeCalledWith(
+      expect(spyCreateWorkspaceTemplate).toHaveBeenCalledWith(
         expect.objectContaining({
           metadata: expect.objectContaining({
             ownerReferences: expect.arrayContaining([
@@ -217,7 +217,7 @@ describe('DevWorkspace client, create', () => {
 
       await client.createDevWorkspace(namespace, testDevWorkspace, undefined);
 
-      expect(spyCreateWorkspace).toBeCalledWith(
+      expect(spyCreateWorkspace).toHaveBeenCalledWith(
         expect.objectContaining({
           spec: expect.objectContaining({
             routingClass: routingClass,
