@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -15,7 +15,7 @@ import { Action } from 'redux';
 
 import { SanityCheckAction } from '@/store/sanityCheckMiddleware';
 
-export type GitConfigUser = api.IGitConfig['gitconfig']['user'];
+export type GitConfig = api.IGitConfig['gitconfig'];
 
 export interface State {
   isLoading: boolean;
