@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -194,7 +194,7 @@ describe('dwPlugins store', () => {
       expect(actions).toEqual(expectedActions);
 
       // check that we fetched the editor on axios
-      expect(mockAxios.get).toBeCalledWith(editorLink);
+      expect(mockAxios.get).toHaveBeenCalledWith(editorLink);
     });
 
     it('should create REQUEST_DW_EDITOR and RECEIVE_DW_EDITOR_ERROR when failed to fetch an editor', async () => {
