@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -24,6 +24,7 @@ import { fetchServerConfig } from '@/services/backend-client/serverConfigApi';
 import { WebsocketClient } from '@/services/backend-client/websocketClient';
 import devfileApi from '@/services/devfileApi';
 import { FactoryParams } from '@/services/helpers/factoryFlow/buildFactoryParams';
+import { che } from '@/services/models';
 import { DevWorkspaceClient } from '@/services/workspace-client/devworkspace/devWorkspaceClient';
 import { AppState } from '@/store';
 import { DevWorkspaceBuilder } from '@/store/__mocks__/devWorkspaceBuilder';
@@ -35,13 +36,13 @@ import { checkRunningWorkspacesLimit } from '@/store/Workspaces/devWorkspaces/ch
 
 import * as testStore from '..';
 
-jest.mock('../../../../services/backend-client/serverConfigApi');
-jest.mock('../../../../services/helpers/delay', () => ({
+jest.mock('@/services/backend-client/serverConfigApi');
+jest.mock('@/services/helpers/delay', () => ({
   delay: jest.fn().mockResolvedValue(undefined),
 }));
 jest.mock('../checkRunningWorkspacesLimit.ts');
 
-jest.mock('../../../../services/backend-client/devworkspaceResourcesApi', () => ({
+jest.mock('@/services/backend-client/devworkspaceResourcesApi', () => ({
   fetchResources: () => `
 apiVersion: workspace.devfile.io/v1alpha2
 kind: DevWorkspaceTemplate
@@ -97,26 +98,33 @@ spec:
 }));
 
 const mockPatchTemplate = jest.fn();
-jest.mock('../../../../services/backend-client/devWorkspaceTemplateApi', () => ({
-  getTemplates: () => [
-    {
-      apiVersion: 'workspace.devfile.io/v1alpha2',
-      kind: 'DevWorkspaceTemplate',
-      metadata: {
-        name: 'che-code',
-        namespace: 'test-che',
-        ownerReferences: [{ uid: 'testDevWorkspaceUID' }],
-      },
+jest.mock('@/services/backend-client/devWorkspaceTemplateApi', () => ({
+  getTemplateByName: (namespace: string, name: string) => ({
+    apiVersion: 'workspace.devfile.io/v1alpha2',
+    kind: 'DevWorkspaceTemplate',
+    metadata: {
+      name,
+      namespace,
+      ownerReferences: [{ uid: 'testDevWorkspaceUID' }],
     },
-  ],
+  }),
   patchTemplate: (templateNamespace, templateName, targetTemplatePatch) =>
     mockPatchTemplate(templateNamespace, templateName, targetTemplatePatch),
 }));
 const mockPatchWorkspace = jest.fn();
-jest.mock('../../../../services/backend-client/devWorkspaceApi', () => ({
+jest.mock('@/services/backend-client/devWorkspaceApi', () => ({
   patchWorkspace: (namespace, workspaceName, patch) =>
     mockPatchWorkspace(namespace, workspaceName, patch),
 }));
+const mockGetEditorName = jest.fn();
+const mockGetLifeTimeMs = jest.fn();
+const mockCheckForEditorUpdate = jest.fn();
+jest.mock('@/store/Workspaces/devWorkspaces/updateEditor', () => ({
+  getEditorName: (workspace: devfileApi.DevWorkspace) => mockGetEditorName(workspace),
+  getLifeTimeMs: (workspace: devfileApi.DevWorkspace) => mockGetLifeTimeMs(workspace),
+  updateEditor: (editorName: string, getState: () => AppState) =>
+    mockCheckForEditorUpdate(editorName, getState),
+}));
 
 // DevWorkspaceClient mocks
 const mockChangeWorkspaceStatus = jest.fn();
@@ -159,7 +167,7 @@ describe('DevWorkspace store, actions', () => {
       { name: 'user-che', attributes: { default: 'true', phase: 'Active' } },
     ]);
     store = storeBuilder
-      .withDwPlugins({}, false, undefined, 'che-incubator/che-code/latest')
+      .withDwPlugins({}, {}, false, undefined, 'che-incubator/che-code/latest')
       .withDwServerConfig({
         defaults: {
           editor: 'che-incubator/che-code/latest',
@@ -333,13 +341,12 @@ describe('DevWorkspace store, actions', () => {
   });
 
   describe('startWorkspace', () => {
-    it('should create REQUEST_DEVWORKSPACE and UPDATE_DEVWORKSPACE when starting DevWorkspace', async () => {
-      const devWorkspace = new DevWorkspaceBuilder().build();
-
-      (checkRunningWorkspacesLimit as jest.Mock).mockImplementation(() => undefined);
+    let devWorkspace: devfileApi.DevWorkspace;
 
+    beforeEach(() => {
       (fetchServerConfig as jest.Mock).mockResolvedValueOnce({});
 
+      devWorkspace = new DevWorkspaceBuilder().build();
       mockChangeWorkspaceStatus.mockResolvedValueOnce(devWorkspace);
       mockManageContainerBuildAttribute.mockResolvedValueOnce(devWorkspace);
       mockManageDebugMode.mockResolvedValueOnce(devWorkspace);
@@ -348,6 +355,50 @@ describe('DevWorkspace store, actions', () => {
       mockUpdate.mockResolvedValueOnce(devWorkspace);
       mockOnStart.mockResolvedValueOnce(devWorkspace);
       mockCheckForDevWorkspaceError.mockReturnValueOnce(devWorkspace);
+    });
+
+    describe('updateEditor', () => {
+      it('should check for update if the target devWorkspase has an editor name and the lifeTime > 30s', async () => {
+        mockGetEditorName.mockReturnValueOnce('che-code');
+        mockGetLifeTimeMs.mockReturnValueOnce(60000);
+
+        mockCheckForEditorUpdate.mockResolvedValueOnce([]);
+
+        const store = storeBuilder.withDevWorkspaces({ workspaces: [devWorkspace] }).build();
+
+        await store.dispatch(testStore.actionCreators.startWorkspace(devWorkspace));
+
+        expect(mockCheckForEditorUpdate).toHaveBeenCalledWith('che-code', store.getState);
+      });
+
+      it('should not check for update if the lifeTime less then 30s', async () => {
+        mockGetEditorName.mockReturnValueOnce('che-code');
+        mockGetLifeTimeMs.mockReturnValueOnce(1000);
+
+        mockCheckForEditorUpdate.mockResolvedValueOnce([]);
+
+        const store = storeBuilder.withDevWorkspaces({ workspaces: [devWorkspace] }).build();
+
+        await store.dispatch(testStore.actionCreators.startWorkspace(devWorkspace));
+
+        expect(mockCheckForEditorUpdate).not.toHaveBeenCalled();
+      });
+
+      it('should not check for update without editor name', async () => {
+        mockGetEditorName.mockReturnValueOnce(undefined);
+        mockGetLifeTimeMs.mockReturnValueOnce(60000);
+
+        mockCheckForEditorUpdate.mockResolvedValueOnce([]);
+
+        const store = storeBuilder.withDevWorkspaces({ workspaces: [devWorkspace] }).build();
+
+        await store.dispatch(testStore.actionCreators.startWorkspace(devWorkspace));
+
+        expect(mockCheckForEditorUpdate).not.toHaveBeenCalled();
+      });
+    });
+    it('should create REQUEST_DEVWORKSPACE and UPDATE_DEVWORKSPACE when starting DevWorkspace', async () => {
+      (checkRunningWorkspacesLimit as jest.Mock).mockImplementation(() => undefined);
 
       const store = storeBuilder.withDevWorkspaces({ workspaces: [devWorkspace] }).build();
 
@@ -377,21 +428,10 @@ describe('DevWorkspace store, actions', () => {
     });
 
     it('should create REQUEST_DEVWORKSPACE and RECEIVE_DEVWORKSPACE_ERROR when failed to start a DevWorkspace', async () => {
-      const devWorkspace = new DevWorkspaceBuilder().build();
-
       (checkRunningWorkspacesLimit as jest.Mock).mockImplementation(() => {
         throw new Error('Limit reached.');
       });
 
-      mockChangeWorkspaceStatus.mockResolvedValueOnce(devWorkspace);
-      mockManageContainerBuildAttribute.mockResolvedValueOnce(devWorkspace);
-      mockManageDebugMode.mockResolvedValueOnce(devWorkspace);
-      mockManagePvcStrategy.mockResolvedValueOnce(devWorkspace);
-      mockOnStart.mockResolvedValueOnce(devWorkspace);
-      mockUpdate.mockResolvedValueOnce(devWorkspace);
-      mockOnStart.mockResolvedValueOnce(devWorkspace);
-      mockCheckForDevWorkspaceError.mockReturnValueOnce(devWorkspace);
-
       const store = storeBuilder.withDevWorkspaces({ workspaces: [devWorkspace] }).build();
 
       try {
@@ -435,6 +475,7 @@ describe('DevWorkspace store, actions', () => {
         .withUID('testDevWorkspaceUID')
         .build();
 
+      mockGetEditorName.mockReturnValueOnce('che-code');
       mockPatchTemplate.mockResolvedValueOnce({});
       mockPatchWorkspace.mockResolvedValueOnce({ devWorkspace: devWorkspace });
 
@@ -479,7 +520,7 @@ describe('DevWorkspace store, actions', () => {
             },
           },
         })
-        .withDwPlugins({}, false, undefined, 'che-incubator/che-code/latest')
+        .withDwPlugins({}, {}, false, undefined, 'che-incubator/che-code/latest')
         .build();
 
       await store.dispatch(
@@ -803,7 +844,11 @@ describe('DevWorkspace store, actions', () => {
       mockOnStart.mockResolvedValueOnce(undefined);
 
       await store.dispatch(
-        testStore.actionCreators.createWorkspaceFromResources(devWorkspace, devWorkspaceTemplate),
+        testStore.actionCreators.createWorkspaceFromResources(
+          devWorkspace,
+          devWorkspaceTemplate,
+          {},
+        ),
       );
 
       const actions = store.getActions();
@@ -843,7 +888,11 @@ describe('DevWorkspace store, actions', () => {
 
       try {
         await store.dispatch(
-          testStore.actionCreators.createWorkspaceFromResources(devWorkspace, devWorkspaceTemplate),
+          testStore.actionCreators.createWorkspaceFromResources(
+            devWorkspace,
+            devWorkspaceTemplate,
+            {},
+          ),
         );
       } catch (e) {
         // no-op
@@ -891,7 +940,11 @@ describe('DevWorkspace store, actions', () => {
 
       it('should provide default editor id when creating a new workspace from resources', async () => {
         await store.dispatch(
-          testStore.actionCreators.createWorkspaceFromResources(devWorkspace, devWorkspaceTemplate),
+          testStore.actionCreators.createWorkspaceFromResources(
+            devWorkspace,
+            devWorkspaceTemplate,
+            {},
+          ),
         );
 
         expect(mockCreateDevWorkspace).toHaveBeenCalledWith(
@@ -906,6 +959,7 @@ describe('DevWorkspace store, actions', () => {
           testStore.actionCreators.createWorkspaceFromResources(
             devWorkspace,
             devWorkspaceTemplate,
+            {},
             'editorid',
           ),
         );
