@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -59,7 +59,17 @@ import {
   selectPluginRegistryUrl,
 } from '@/store/ServerConfig/selectors';
 import { checkRunningWorkspacesLimit } from '@/store/Workspaces/devWorkspaces/checkRunningWorkspacesLimit';
+import {
+  getEditorImage,
+  updateDevWorkspaceTemplate,
+  updateEditorDevfile,
+} from '@/store/Workspaces/devWorkspaces/editorImage';
 import { selectDevWorkspacesResourceVersion } from '@/store/Workspaces/devWorkspaces/selectors';
+import {
+  getEditorName,
+  getLifeTimeMs,
+  updateEditor,
+} from '@/store/Workspaces/devWorkspaces/updateEditor';
 
 export const onStatusChangeCallbacks = new Map<string, (status: string) => void>();
 
@@ -176,7 +186,7 @@ export type ActionCreators = {
   ) => AppThunk<KnownAction, Promise<void>>;
   createWorkspaceFromDevfile: (
     devfile: devfileApi.Devfile,
-    attributes: Partial<FactoryParams>,
+    params: Partial<FactoryParams>,
     optionalFilesContent: {
       [fileName: string]: string;
     },
@@ -184,7 +194,9 @@ export type ActionCreators = {
   createWorkspaceFromResources: (
     devWorkspace: devfileApi.DevWorkspace,
     devWorkspaceTemplate: devfileApi.DevWorkspaceTemplate,
-    editorId?: string,
+    params: Partial<FactoryParams>,
+    // it could be editorId or editorContent
+    editor?: string,
   ) => AppThunk<KnownAction, Promise<void>>;
 
   handleWebSocketMessage: (
@@ -331,6 +343,12 @@ export const actionCreators: ActionCreators = {
 
         workspace = await getDevWorkspaceClient().manageDebugMode(workspace, debugWorkspace);
 
+        const editorName = getEditorName(workspace);
+        const lifeTimeMs = getLifeTimeMs(workspace);
+        if (editorName && lifeTimeMs > 30000) {
+          await updateEditor(editorName, getState);
+        }
+
         const startingWorkspace = await getDevWorkspaceClient().changeWorkspaceStatus(
           workspace,
           true,
@@ -530,9 +548,10 @@ export const actionCreators: ActionCreators = {
 
   createWorkspaceFromResources:
     (
-      devWorkspaceResource: devfileApi.DevWorkspace,
-      devWorkspaceTemplateResource: devfileApi.DevWorkspaceTemplate,
-      editorId?: string,
+      devWorkspace: devfileApi.DevWorkspace,
+      devWorkspaceTemplate: devfileApi.DevWorkspaceTemplate,
+      params: Partial<FactoryParams>,
+      editor?: string,
     ): AppThunk<KnownAction, Promise<void>> =>
     async (dispatch, getState): Promise<void> => {
       const state = getState();
@@ -540,7 +559,7 @@ export const actionCreators: ActionCreators = {
       const openVSXUrl = selectOpenVSXUrl(state);
       const pluginRegistryUrl = selectPluginRegistryUrl(state);
       const pluginRegistryInternalUrl = selectPluginRegistryInternalUrl(state);
-      const cheEditor = editorId ? editorId : selectDefaultEditor(state);
+      const cheEditor = editor ? editor : selectDefaultEditor(state);
       const defaultNamespace = defaultKubernetesNamespace.name;
 
       try {
@@ -552,7 +571,7 @@ export const actionCreators: ActionCreators = {
         /* create a new DevWorkspace */
         const createResp = await getDevWorkspaceClient().createDevWorkspace(
           defaultNamespace,
-          devWorkspaceResource,
+          devWorkspace,
           cheEditor,
         );
 
@@ -571,11 +590,12 @@ export const actionCreators: ActionCreators = {
           app => app.id === ApplicationId.CLUSTER_CONSOLE,
         );
 
+        devWorkspaceTemplate = updateDevWorkspaceTemplate(devWorkspaceTemplate, params.editorImage);
         /* create a new DevWorkspaceTemplate */
         await getDevWorkspaceClient().createDevWorkspaceTemplate(
           defaultNamespace,
           createResp.devWorkspace,
-          devWorkspaceTemplateResource,
+          devWorkspaceTemplate,
           pluginRegistryUrl,
           pluginRegistryInternalUrl,
           openVSXUrl,
@@ -652,6 +672,11 @@ export const actionCreators: ActionCreators = {
 
         defaultsDevfile.metadata.name = workspace.metadata.name;
         delete defaultsDevfile.metadata.generateName;
+
+        const editorImage = getEditorImage(workspace);
+        if (editorImage) {
+          editorContent = updateEditorDevfile(editorContent, editorImage);
+        }
         const resourcesContent = await fetchResources({
           pluginRegistryUrl,
           devfileContent: dump(defaultsDevfile),
@@ -724,18 +749,13 @@ export const actionCreators: ActionCreators = {
           openVSXUrl,
           clusterConsole,
         );
-        const templates = await DwtApi.getTemplates(workspace.metadata.namespace);
-        const targetTemplate = templates.find(template => {
-          const ownerReferences = template.metadata?.ownerReferences || [];
-          return (
-            ownerReferences.find(
-              ownerReference => ownerReference.uid === workspace.metadata.uid,
-            ) !== undefined
-          );
-        });
-        const templateName = targetTemplate?.metadata?.name;
-        const templateNamespace = targetTemplate?.metadata?.namespace;
-        if (!templateName || !templateNamespace) {
+        let targetTemplate: devfileApi.DevWorkspaceTemplate | undefined;
+        const templateName = getEditorName(workspace);
+        const templateNamespace = workspace.metadata.namespace;
+        if (templateName && templateNamespace) {
+          targetTemplate = await DwtApi.getTemplateByName(templateNamespace, templateName);
+        }
+        if (!templateName || !templateNamespace || !targetTemplate) {
           throw new Error('Cannot define the target template');
         }
 
@@ -807,7 +827,7 @@ export const actionCreators: ActionCreators = {
   createWorkspaceFromDevfile:
     (
       devfile: devfileApi.Devfile,
-      attributes: Partial<FactoryParams>,
+      params: Partial<FactoryParams>,
       optionalFilesContent: {
         [fileName: string]: string;
       },
@@ -820,7 +840,7 @@ export const actionCreators: ActionCreators = {
       let editorContent: string | undefined;
       let editorYamlUrl: string | undefined;
       // do we have an optional editor parameter ?
-      let editor = attributes.cheEditor;
+      let editor = params.cheEditor;
       if (editor) {
         const response = await getEditor(editor, dispatch, getState, pluginRegistryUrl);
         if (response.content) {
@@ -867,6 +887,7 @@ export const actionCreators: ActionCreators = {
           const error = selectSanityCheckError(getState());
           throw new Error(error);
         }
+        editorContent = updateEditorDevfile(editorContent, params.editorImage);
         const resourcesContent = await fetchResources({
           pluginRegistryUrl,
           devfileContent: dump(devfile),
@@ -912,7 +933,8 @@ export const actionCreators: ActionCreators = {
         actionCreators.createWorkspaceFromResources(
           devWorkspaceResource,
           devWorkspaceTemplateResource,
-          editor,
+          params,
+          editor ? editor : editorContent,
         ),
       );
     },
