@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -14,6 +14,7 @@ import { V1alpha2DevWorkspaceStatus, V1alpha2DevWorkspaceStatusConditions } from
 
 import devfileApi from '@/services/devfileApi';
 import { DevWorkspacePlugin } from '@/services/devfileApi/devWorkspace';
+import { DevWorkspaceSpecTemplateAttribute } from '@/services/devfileApi/devWorkspace/spec/template';
 import getRandomString from '@/services/helpers/random';
 import { DevWorkspaceStatus } from '@/services/helpers/types';
 
@@ -132,6 +133,10 @@ export class DevWorkspaceBuilder {
     this.workspace.spec.template.projects = projects;
     return this;
   }
+  withTemplateAttributes(attributes: DevWorkspaceSpecTemplateAttribute): DevWorkspaceBuilder {
+    this.workspace.spec.template.attributes = attributes;
+    return this;
+  }
 
   build(): devfileApi.DevWorkspace {
     return this.workspace;
