@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -11,13 +11,14 @@
  */
 
 import { FactoryResolver, FactoryResolverScmInfo } from '@/services/helpers/types';
+import { che } from '@/services/models';
 
 export class FactoryResolverBuilder {
   private factoryResolver = {
     v: '4.0',
   } as FactoryResolver;
 
-  withDevfile(devfile: api.che.workspace.devfile.Devfile): FactoryResolverBuilder {
+  withDevfile(devfile: che.api.workspace.devfile.Devfile): FactoryResolverBuilder {
     this.factoryResolver.devfile = devfile;
     return this;
   }
@@ -27,11 +28,6 @@ export class FactoryResolverBuilder {
     return this;
   }
 
-  withLocation(location: string): FactoryResolverBuilder {
-    this.factoryResolver.location = location;
-    return this;
-  }
-
   withScmInfo(scmInfo: FactoryResolverScmInfo): FactoryResolverBuilder {
     this.factoryResolver['scm_info'] = scmInfo;
     return this;
