@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -18,6 +18,7 @@ import { ThunkDispatch } from 'redux-thunk';
 
 import { BrandingData } from '@/services/bootstrap/branding.constant';
 import devfileApi from '@/services/devfileApi';
+import { che } from '@/services/models';
 import mockThunk from '@/store/__mocks__/thunk';
 import { State as BrandingState } from '@/store/Branding';
 import { DevWorkspaceResources, State as DevfileRegistriesState } from '@/store/DevfileRegistries';
@@ -30,6 +31,7 @@ import {
 import { IGitOauth } from '@/store/GitOauthConfig/types';
 import { State as InfrastructureNamespaceState } from '@/store/InfrastructureNamespaces';
 import { State as PluginsState } from '@/store/Plugins/chePlugins';
+import { PluginDefinition } from '@/store/Plugins/devWorkspacePlugins';
 import { State as LogsState } from '@/store/Pods/Logs';
 import { State as UserProfileState } from '@/store/User/Profile';
 import { State as WorkspacesState } from '@/store/Workspaces';
@@ -379,19 +381,15 @@ export class FakeStoreBuilder {
   }
 
   public withDwPlugins(
-    plugins: {
-      [location: string]: {
-        plugin?: devfileApi.Devfile;
-        url: string;
-        error?: string;
-      };
-    },
+    plugins: { [url: string]: PluginDefinition },
+    editors: { [url: string]: PluginDefinition },
     isLoading = false,
     defaultEditorError?: string,
     defaultEditorName?: string,
   ) {
     this.state.dwPlugins.defaultEditorError = defaultEditorError;
     this.state.dwPlugins.plugins = Object.assign({}, plugins);
+    this.state.dwPlugins.editors = Object.assign({}, editors);
     this.state.dwPlugins.isLoading = isLoading;
     this.state.dwPlugins.defaultEditorName = defaultEditorName;
 
